==> haskell-tar-conduit-0.4.1-101-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tar-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tar-conduit
version:              0.4.1
visibility:           public
id:                   tar-conduit-0.4.1-sJBbEdd5VDEvmo1DgFhnM
key:                  tar-conduit-0.4.1-sJBbEdd5VDEvmo1DgFhnM
license:              MIT
maintainer:
    michael@snoyman.com, bartavelle@gmail.com, alexey@kuleshevi.ch

author:               Michael Snoyman
homepage:             https://github.com/snoyberg/tar-conduit#readme
synopsis:             Extract and create tar files using conduit for streaming
description:
    Please see README.md. This is just filler to avoid warnings.

category:             Data Conduit
abi:                  c21a7db940c9dd996f3d39f6fa0559dd
exposed:              True
exposed-modules:      Data.Conduit.Tar Data.Conduit.Tar.Types
hidden-modules:       Data.Conduit.Tar.Unix
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tar-conduit-0.4.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tar-conduit-0.4.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tar-conduit-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tar-conduit
hs-libraries:         HStar-conduit-0.4.1-sJBbEdd5VDEvmo1DgFhnM
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-GHyJy0fEO4I5Y3sMB26bfT containers-0.6.7
    directory-1.3.7.1 filepath-1.4.2.2 mtl-2.2.2
    safe-exceptions-0.1.7.4-3Z5aHvleGFbLTLwdzNM383 text-2.0.2
    unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-tar-conduit/html/tar-conduit.haddock
haddock-html:         /usr/share/doc/haskell-tar-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tar-conduit-0.4.1-102-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tar-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tar-conduit
version:              0.4.1
visibility:           public
id:                   tar-conduit-0.4.1-DX5eg438P842lR7r2MM8A7
key:                  tar-conduit-0.4.1-DX5eg438P842lR7r2MM8A7
license:              MIT
maintainer:
    michael@snoyman.com, bartavelle@gmail.com, alexey@kuleshevi.ch

author:               Michael Snoyman
homepage:             https://github.com/snoyberg/tar-conduit#readme
synopsis:             Extract and create tar files using conduit for streaming
description:
    Please see README.md. This is just filler to avoid warnings.

category:             Data Conduit
abi:                  1eef9ba2c8528197674682b18cf103bd
exposed:              True
exposed-modules:      Data.Conduit.Tar Data.Conduit.Tar.Types
hidden-modules:       Data.Conduit.Tar.Unix
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tar-conduit-0.4.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tar-conduit-0.4.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tar-conduit-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tar-conduit
hs-libraries:         HStar-conduit-0.4.1-DX5eg438P842lR7r2MM8A7
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-LsCA1bXaHAtCkLdZq4D2B7 containers-0.6.7
    directory-1.3.7.1 filepath-1.4.2.2 mtl-2.2.2
    safe-exceptions-0.1.7.4-I8MUkOZu8EQha4YZKTDJS text-2.0.2 unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-tar-conduit/html/tar-conduit.haddock
haddock-html:         /usr/share/doc/haskell-tar-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
